Application

Struct Application 

pub struct Application { /* private fields */ }
Bootstrapped Nidus application.

Implementations

Source

impl Application

pub fn new(container: Container, modules: ModuleGraph) -> Self

Creates an application from an already validated container and graph.

pub fn with_lifecycle( container: Container, modules: ModuleGraph, lifecycle: LifecycleRunner, ) -> Self

Creates an application from an already validated container, graph, and lifecycle runner.

pub fn container(&self) -> &Container

Returns the application dependency container.

pub fn modules(&self) -> &ModuleGraph

Returns the validated module graph.

pub async fn shutdown(&self) -> Result<()>

Runs every application shutdown hook in reverse registration order.

If hooks fail, cleanup continues and the first shutdown error is returned after all hooks have been attempted.